@@ -14,20 +14,12 @@
 #define _POSIX_C_SOURCE 200112L  ///< For XSI-compliant strerror_r().
 
 #include <assert.h>
-#include <errno.h>
 #include <stdint.h>
 #include <string.h>
 #include <sys/socket.h>
 #include <netinet/in.h>
 
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wpedantic"
-#include <ell/hashmap.h>
-#include <ell/uintset.h>
-#include <ell/util.h>
-#include <ell/log.h>
-#include <ell/random.h>
-#pragma GCC diagnostic pop
+#include <ell/ell.h>
 
 #include <mptcpd/private/murmur_hash.h>
 #include <mptcpd/private/id_manager.h>
