@@ -15,9 +15,7 @@
 #include <errno.h>
 #include <stdio.h>
 
-#include <ell/genl.h>
-#include <ell/util.h>  // For L_STRINGIFY needed by l_error(), etc.
-#include <ell/log.h>
+#include <ell/ell.h>
 
 #include "commands.h"
 #include "netlink_pm.h"
@@ -155,8 +153,11 @@ static bool append_remote_addr_attr(struct l_genl_msg *msg,
 static int mptcp_org_add_addr(struct mptcpd_pm *pm,
                               struct sockaddr *addr,
                               mptcpd_aid_t id,
-                              mptcpd_token_t token)
+                              mptcpd_token_t token,
+                              bool listener)
 {
+	(void) listener;
+
         /*
           Payload:
               Token
