@@ -20,12 +20,14 @@ static void plugin_noop_new_connection(mptcpd_token_t token,
                                        struct sockaddr const *laddr,
                                        struct sockaddr const *raddr,
                                        bool server_side,
+                                       bool deny_join_id0,
                                        struct mptcpd_pm *pm)
 {
         (void) token;
         (void) laddr;
         (void) raddr;
         (void) server_side;
+        (void) deny_join_id0;
         (void) pm;
 }
 
@@ -34,12 +36,14 @@ static void plugin_noop_connection_established(
         struct sockaddr const *laddr,
         struct sockaddr const *raddr,
         bool server_side,
+        bool deny_join_id0,
         struct mptcpd_pm *pm)
 {
         (void) token;
         (void) laddr;
         (void) raddr;
         (void) server_side;
+        (void) deny_join_id0;
         (void) pm;
 }
 
@@ -87,12 +91,14 @@ static void plugin_noop_subflow_closed(mptcpd_token_t token,
                                        struct sockaddr const *laddr,
                                        struct sockaddr const *raddr,
                                        bool backup,
+                                       uint8_t error,
                                        struct mptcpd_pm *pm)
 {
         (void) token;
         (void) laddr;
         (void) raddr;
         (void) backup;
+        (void) error;
         (void) pm;
 }
 
