@@ -37,6 +37,7 @@ static void plugin_one_new_connection(mptcpd_token_t token,
                                       struct sockaddr const *laddr,
                                       struct sockaddr const *raddr,
                                       bool server_side,
+                                      bool deny_join_id0,
                                       struct mptcpd_pm *pm)
 {
         (void) pm;
@@ -47,6 +48,7 @@ static void plugin_one_new_connection(mptcpd_token_t token,
         assert(sockaddr_is_equal(laddr, local_addr));
         assert(sockaddr_is_equal(raddr, remote_addr));
         assert(server_side == test_server_side_1);
+        assert(deny_join_id0 == test_deny_join_id0_1);
 
         ++call_count.new_connection;
 }
@@ -56,6 +58,7 @@ static void plugin_one_connection_established(
         struct sockaddr const *laddr,
         struct sockaddr const *raddr,
         bool server_side,
+        bool deny_join_id0,
         struct mptcpd_pm *pm)
 {
         (void) pm;
@@ -66,6 +69,7 @@ static void plugin_one_connection_established(
         assert(sockaddr_is_equal(laddr, local_addr));
         assert(sockaddr_is_equal(raddr, remote_addr));
         assert(server_side == test_server_side_1);
+        assert(deny_join_id0 == test_deny_join_id0_1);
 
         ++call_count.connection_established;
 }
@@ -126,6 +130,7 @@ static void plugin_one_subflow_closed(mptcpd_token_t token,
                                       struct sockaddr const *laddr,
                                       struct sockaddr const *raddr,
                                       bool backup,
+                                      uint8_t error,
                                       struct mptcpd_pm *pm)
 {
         (void) pm;
@@ -134,6 +139,7 @@ static void plugin_one_subflow_closed(mptcpd_token_t token,
         assert(sockaddr_is_equal(laddr, local_addr));
         assert(sockaddr_is_equal(raddr, remote_addr));
         assert(backup == test_backup_1);
+        assert(error == test_error_1);
 
         ++call_count.subflow_closed;
 }
