@@ -8,8 +8,7 @@
  */
 
 #include <arpa/inet.h>  // htonl() and htons()
-#include <ell/log.h>
-#include <ell/test.h>
+#include <ell/ell.h>
 
 #include <mptcpd/addr_info.h>
 #include <mptcpd/private/addr_info.h>
@@ -46,7 +45,7 @@ static void test_addr_info(void const *test_data)
 
         in_addr_t const addr = htonl(0xC0000201);  // 192.0.2.1
         in_port_t const port = htons(0x1234);
-        
+
         struct mptcpd_addr_info info = {
                 .id    = 5,
                 .flags = 10,
